Purchase Request Quotation Module
#################################

The *Purchase Request Quotation Module* allows users to ask quotations
from purchase requests to different suppliers.

.. toctree::
   :maxdepth: 2

   design
   releases
